<?php

declare(strict_types=1);

namespace Rowlinson\Api;

use Rowlinson\Api\Collections\PaginatedCollection;
use Rowlinson\Api\Responses\Invites\InviteResponse;

class InviteClient extends AbstractClient
{
    /**
     * List all pending invites
     *
     * @return PaginatedCollection<InviteResponse>
     */
    public function listAll(): PaginatedCollection
    {
        $response = $this->get('users/invites');

        /** @var array<InviteResponse> $invites */
        $invites = $this->serializer->deserialize(
            (string)$response->getBody(),
            'array<' . InviteResponse::class . '>', // @phpstan-ignore-line
            'json'
        );

        return new PaginatedCollection($invites, 1, count($invites), count($invites));
    }
}
